summaryrefslogtreecommitdiff
path: root/framework
diff options
context:
space:
mode:
authorTor Lillqvist <tml@iki.fi>2013-05-15 10:42:04 +0300
committerTor Lillqvist <tml@iki.fi>2013-05-15 11:14:28 +0300
commitcb6d67c21f11811c5bc023b9565c1c1b1f4081fa (patch)
treeff8a4b192a2ca846d32111732563432244135910 /framework
parent1a357b7394ac7b48b72821bff1aae4706265d7a4 (diff)
Spelling "separate" (etc) correctly is hard
Diffstat (limited to 'framework')
-rw-r--r--framework/inc/classes/protocolhandlercache.hxx2
-rw-r--r--framework/inc/helper/mischelper.hxx2
-rw-r--r--framework/inc/helper/tagwindowasmodified.hxx2
-rw-r--r--framework/inc/jobs/joburl.hxx6
-rw-r--r--framework/inc/queries.h24
-rw-r--r--framework/inc/services/logindialog.hxx2
-rw-r--r--framework/source/accelerators/presethandler.cxx10
-rw-r--r--framework/source/accelerators/storageholder.cxx26
-rw-r--r--framework/source/constant/containerquery.cxx4
-rw-r--r--framework/source/fwe/classes/framelistanalyzer.cxx2
-rw-r--r--framework/source/fwi/classes/protocolhandlercache.cxx4
-rw-r--r--framework/source/inc/constant/containerquery.hxx4
-rw-r--r--framework/source/inc/loadenv/loadenv.hxx2
-rw-r--r--framework/source/jobs/joburl.cxx8
-rw-r--r--framework/source/services/frame.cxx2
-rw-r--r--framework/source/services/pathsettings.cxx2
-rw-r--r--framework/source/uielement/langselectionstatusbarcontroller.cxx2
17 files changed, 52 insertions, 52 deletions
diff --git a/framework/inc/classes/protocolhandlercache.hxx b/framework/inc/classes/protocolhandlercache.hxx
index 1f7963725fea..109bddeb28bc 100644
--- a/framework/inc/classes/protocolhandlercache.hxx
+++ b/framework/inc/classes/protocolhandlercache.hxx
@@ -34,7 +34,7 @@ namespace framework{
#define PACKAGENAME_PROTOCOLHANDLER DECLARE_ASCII("Office.ProtocolHandler" ) /// name of our configuration package
-#define CFG_PATH_SEPERATOR DECLARE_ASCII("/" ) /// separator for configuration paths
+#define CFG_PATH_SEPARATOR DECLARE_ASCII("/" ) /// separator for configuration paths
#define SETNAME_HANDLER DECLARE_ASCII("HandlerSet" ) /// name of configuration set inside package
#define PROPERTY_PROTOCOLS DECLARE_ASCII("Protocols" ) /// properties of a protocol handler
diff --git a/framework/inc/helper/mischelper.hxx b/framework/inc/helper/mischelper.hxx
index 0b26720bfd20..672f67fa620d 100644
--- a/framework/inc/helper/mischelper.hxx
+++ b/framework/inc/helper/mischelper.hxx
@@ -65,7 +65,7 @@ enum LangMenuIDs
MID_LANG_SEL_RESET,
MID_LANG_SEL_MORE,
- MID_LANG_PARA_SEPERATOR,
+ MID_LANG_PARA_SEPARATOR,
MID_LANG_PARA_STRING,
MID_LANG_PARA_1,
diff --git a/framework/inc/helper/tagwindowasmodified.hxx b/framework/inc/helper/tagwindowasmodified.hxx
index fa3c506c13c7..a17e1dc5416d 100644
--- a/framework/inc/helper/tagwindowasmodified.hxx
+++ b/framework/inc/helper/tagwindowasmodified.hxx
@@ -39,7 +39,7 @@ namespace framework{
/*-************************************************************************************************************//**
@short listen for modify events on model and tag frame container window so it can react accordingly
- @descr Used e.g. by our MAC port where such state is shown seperately on some controls of the
+ @descr Used e.g. by our MAC port where such state is shown separately on some controls of the
title bar.
@base ThreadHelpBase
diff --git a/framework/inc/jobs/joburl.hxx b/framework/inc/jobs/joburl.hxx
index f6e06837c417..cfc91589c4dc 100644
--- a/framework/inc/jobs/joburl.hxx
+++ b/framework/inc/jobs/joburl.hxx
@@ -43,15 +43,15 @@ namespace framework{
#define JOBURL_SERVICE_STR "service="
#define JOBURL_SERVICE_LEN 8
-#define JOBURL_PART_SEPERATOR ';'
-#define JOBURL_PARTARGS_SEPERATOR ','
+#define JOBURL_PART_SEPARATOR ';'
+#define JOBURL_PARTARGS_SEPARATOR ','
//_______________________________________
/**
@short can be used to parse, validate and work with job URL's
@descr Job URLs are specified by the following syntax:
vnd.sun.star.job:{[event=<name>]|[alias=<name>]|[service=<name>]}
- This class can analyze this structure and seperate it into his different parts.
+ This class can analyze this structure and separate it into his different parts.
After doing that these parts are accessible by the methods of this class.
*/
class JobURL : private ThreadHelpBase
diff --git a/framework/inc/queries.h b/framework/inc/queries.h
index 94f6c32cda6e..26f60cb93d68 100644
--- a/framework/inc/queries.h
+++ b/framework/inc/queries.h
@@ -60,8 +60,8 @@ namespace framework{
default_first set default filter on top of return list false
case_sensitive compare "sort_prop" case sensitive false
*//*-*************************************************************************************************************/
-#define SEPERATOR_QUERYPARAM ((sal_Unicode)':')
-#define SEPERATOR_QUERYPARAMVALUE ((sal_Unicode)'=')
+#define SEPARATOR_QUERYPARAM ((sal_Unicode)':')
+#define SEPARATOR_QUERYPARAMVALUE ((sal_Unicode)'=')
#define QUERYPARAM_IFLAGS DECLARE_ASCII("iflags" )
#define QUERYPARAM_EFLAGS DECLARE_ASCII("eflags" )
@@ -112,11 +112,11 @@ class QueryBuilder
//---------------------------------------------------------------------------------------------------------
void addParam( const OUString& sParam, const OUString& sValue = OUString() )
{
- m_sParams.append( SEPERATOR_QUERYPARAM );
+ m_sParams.append( SEPARATOR_QUERYPARAM );
m_sParams.append( sParam );
if( sValue.getLength() > 0 )
{
- m_sParams.append( SEPERATOR_QUERYPARAMVALUE );
+ m_sParams.append( SEPARATOR_QUERYPARAMVALUE );
m_sParams.append( sValue );
}
}
@@ -236,7 +236,7 @@ class QueryAnalyzer
// Try to find base of it and safe it for faster access as enum value!
sal_Int32 nToken = 0;
OUString sParam;
- OUString sBase = sNewQuery.getToken( 0, SEPERATOR_QUERYPARAM, nToken );
+ OUString sBase = sNewQuery.getToken( 0, SEPARATOR_QUERYPARAM, nToken );
if (sBase.equalsIgnoreAsciiCase(BASE_QUERY_ALL))
m_eQuery = E_ALL;
@@ -262,7 +262,7 @@ class QueryAnalyzer
// Try to get additional parameters ...
while( nToken >= 0 )
{
- sParam = sNewQuery.getToken( 0, SEPERATOR_QUERYPARAM, nToken );
+ sParam = sNewQuery.getToken( 0, SEPARATOR_QUERYPARAM, nToken );
// "default_first"
if( sParam.startsWith( QUERYPARAM_DEFAULT_FIRST ) )
{
@@ -287,30 +287,30 @@ class QueryAnalyzer
else if( sParam.startsWith( QUERYPARAM_IFLAGS ) )
{
sal_Int32 nSubToken = 0;
- sParam.getToken( 0, SEPERATOR_QUERYPARAMVALUE, nSubToken );
+ sParam.getToken( 0, SEPARATOR_QUERYPARAMVALUE, nSubToken );
if( nSubToken > 0 )
{
- m_nIFlags = sParam.getToken( 0, SEPERATOR_QUERYPARAMVALUE, nSubToken ).toInt32();
+ m_nIFlags = sParam.getToken( 0, SEPARATOR_QUERYPARAMVALUE, nSubToken ).toInt32();
}
}
// "eflags=<mask>"
else if( sParam.startsWith( QUERYPARAM_EFLAGS ) )
{
sal_Int32 nSubToken = 0;
- sParam.getToken( 0, SEPERATOR_QUERYPARAMVALUE, nSubToken );
+ sParam.getToken( 0, SEPARATOR_QUERYPARAMVALUE, nSubToken );
if( nSubToken > 0 )
{
- m_nEFlags = sParam.getToken( 0, SEPERATOR_QUERYPARAMVALUE, nSubToken ).toInt32();
+ m_nEFlags = sParam.getToken( 0, SEPARATOR_QUERYPARAMVALUE, nSubToken ).toInt32();
}
}
// "sort_prop=<[name,uiname]>"
else if( sParam.startsWith( QUERYPARAM_SORT_PROP ) )
{
sal_Int32 nSubToken = 0;
- sParam.getToken( 0, SEPERATOR_QUERYPARAMVALUE, nSubToken );
+ sParam.getToken( 0, SEPARATOR_QUERYPARAMVALUE, nSubToken );
if( nSubToken > 0 )
{
- OUString sParamValue = sParam.getToken( 0, SEPERATOR_QUERYPARAMVALUE, nSubToken );
+ OUString sParamValue = sParam.getToken( 0, SEPARATOR_QUERYPARAMVALUE, nSubToken );
if( sParamValue.startsWith( QUERYPARAMVALUE_SORT_PROP_NAME ) )
m_eSortProp = E_NAME;
else if( sParamValue.startsWith( QUERYPARAMVALUE_SORT_PROP_UINAME ) )
diff --git a/framework/inc/services/logindialog.hxx b/framework/inc/services/logindialog.hxx
index cb50a0628c69..f5a65759200f 100644
--- a/framework/inc/services/logindialog.hxx
+++ b/framework/inc/services/logindialog.hxx
@@ -57,7 +57,7 @@ namespace framework{
#error "name of login profile unknown!"
#endif
-#define UNCPATHSEPERATOR sal_Unicode(0x002F)
+#define UNCPATHSEPARATOR sal_Unicode(0x002F)
// Use follow keys in follow order.
// [Global]
diff --git a/framework/source/accelerators/presethandler.cxx b/framework/source/accelerators/presethandler.cxx
index 6cc93c36efec..7735ea59d41d 100644
--- a/framework/source/accelerators/presethandler.cxx
+++ b/framework/source/accelerators/presethandler.cxx
@@ -50,7 +50,7 @@
#define FILE_EXTENSION DECLARE_ASCII(".xml")
-#define PATH_SEPERATOR DECLARE_ASCII("/")
+#define PATH_SEPARATOR DECLARE_ASCII("/")
static const ::sal_Int32 ID_CORRUPT_UICONFIG_SHARE = 1;
static const ::sal_Int32 ID_CORRUPT_UICONFIG_USER = 2;
@@ -423,7 +423,7 @@ void PresetHandler::connectToResource( PresetHandler::EConfigType
case E_GLOBAL :
{
sRelPathBuf.append(SUBSTORAGE_GLOBAL);
- sRelPathBuf.append(PATH_SEPERATOR );
+ sRelPathBuf.append(PATH_SEPARATOR );
sRelPathBuf.append(sResource );
sRelPathShare = sRelPathBuf.makeStringAndClear();
sRelPathUser = sRelPathShare;
@@ -436,9 +436,9 @@ void PresetHandler::connectToResource( PresetHandler::EConfigType
case E_MODULES :
{
sRelPathBuf.append(SUBSTORAGE_MODULES);
- sRelPathBuf.append(PATH_SEPERATOR );
+ sRelPathBuf.append(PATH_SEPARATOR );
sRelPathBuf.append(sModule );
- sRelPathBuf.append(PATH_SEPERATOR );
+ sRelPathBuf.append(PATH_SEPARATOR );
sRelPathBuf.append(sResource );
sRelPathShare = sRelPathBuf.makeStringAndClear();
sRelPathUser = sRelPathShare;
@@ -846,7 +846,7 @@ css::uno::Reference< css::embed::XStorage > PresetHandler::impl_openLocalizedPat
// Otherwhise we have no acc config at all, which can make other trouble.
OUString sLocalizedPath;
sLocalizedPath = sPath;
- sLocalizedPath += PATH_SEPERATOR;
+ sLocalizedPath += PATH_SEPARATOR;
if (pLocaleFolder != lSubFolders.end())
sLocalizedPath += *pLocaleFolder;
else
diff --git a/framework/source/accelerators/storageholder.cxx b/framework/source/accelerators/storageholder.cxx
index 40d875c2b51e..395c9943b7a3 100644
--- a/framework/source/accelerators/storageholder.cxx
+++ b/framework/source/accelerators/storageholder.cxx
@@ -40,9 +40,9 @@
#include <com/sun/star/io/XSeekable.hpp>
-#define PATH_SEPERATOR_ASCII "/"
-#define PATH_SEPERATOR_UNICODE ((sal_Unicode)'/')
-#define PATH_SEPERATOR OUString(PATH_SEPERATOR_ASCII)
+#define PATH_SEPARATOR_ASCII "/"
+#define PATH_SEPARATOR_UNICODE ((sal_Unicode)'/')
+#define PATH_SEPARATOR OUString(PATH_SEPARATOR_ASCII)
namespace framework
@@ -125,7 +125,7 @@ css::uno::Reference< css::embed::XStorage > StorageHolder::openPath(const OUStri
const OUString& sChild = *pIt;
OUString sCheckPath (sRelPath);
sCheckPath += sChild;
- sCheckPath += PATH_SEPERATOR;
+ sCheckPath += PATH_SEPARATOR;
// SAFE -> ------------------------------
aReadLock.lock();
@@ -177,7 +177,7 @@ css::uno::Reference< css::embed::XStorage > StorageHolder::openPath(const OUStri
xParent = xChild;
sRelPath += sChild;
- sRelPath += PATH_SEPERATOR;
+ sRelPath += PATH_SEPARATOR;
}
// TODO think about return last storage as working storage ... but dont caching it inside this holder!
@@ -206,7 +206,7 @@ StorageHolder::TStorageList StorageHolder::getAllPathStorages(const OUString& sP
const OUString& sChild = *pIt;
OUString sCheckPath (sRelPath);
sCheckPath += sChild;
- sCheckPath += PATH_SEPERATOR;
+ sCheckPath += PATH_SEPARATOR;
TPath2StorageInfo::iterator pCheck = m_lStorages.find(sCheckPath);
if (pCheck == m_lStorages.end())
@@ -221,7 +221,7 @@ StorageHolder::TStorageList StorageHolder::getAllPathStorages(const OUString& sP
lStoragesOfPath.push_back(rInfo.Storage);
sRelPath += sChild;
- sRelPath += PATH_SEPERATOR;
+ sRelPath += PATH_SEPARATOR;
}
aReadLock.unlock();
@@ -276,7 +276,7 @@ void StorageHolder::closePath(const OUString& rPath)
{
OUString sCurrentRelPath = sParentPath;
sCurrentRelPath += *pIt1;
- sCurrentRelPath += PATH_SEPERATOR;
+ sCurrentRelPath += PATH_SEPARATOR;
*pIt1 = sCurrentRelPath;
sParentPath = sCurrentRelPath;
}
@@ -438,7 +438,7 @@ css::uno::Reference< css::embed::XStorage > StorageHolder::getParentStorage(cons
for (i=0; i<c-1; ++i)
{
sParentPath += lFolders[i];
- sParentPath += PATH_SEPERATOR;
+ sParentPath += PATH_SEPARATOR;
}
TPath2StorageInfo::const_iterator pParent = m_lStorages.find(sParentPath);
@@ -554,7 +554,7 @@ OUString StorageHolder::impl_st_normPath(const OUString& sPath)
OUString sNormedPath = sPath;
// "/bla" => "bla" && "/" => "" (!)
- if (sNormedPath.indexOf(PATH_SEPERATOR) == 0)
+ if (sNormedPath.indexOf(PATH_SEPARATOR) == 0)
sNormedPath += sNormedPath.copy(1);
// "/" => "" || "" => "" ?
@@ -562,8 +562,8 @@ OUString StorageHolder::impl_st_normPath(const OUString& sPath)
return OUString();
// "bla" => "bla/"
- if (sNormedPath.lastIndexOf(PATH_SEPERATOR) != (sNormedPath.getLength()-1))
- sNormedPath += PATH_SEPERATOR;
+ if (sNormedPath.lastIndexOf(PATH_SEPARATOR) != (sNormedPath.getLength()-1))
+ sNormedPath += PATH_SEPARATOR;
return sNormedPath;
}
@@ -575,7 +575,7 @@ OUStringList StorageHolder::impl_st_parsePath(const OUString& sPath)
sal_Int32 i = 0;
while (true)
{
- OUString sToken = sPath.getToken(0, PATH_SEPERATOR_UNICODE, i);
+ OUString sToken = sPath.getToken(0, PATH_SEPARATOR_UNICODE, i);
if (i < 0)
break;
lToken.push_back(sToken);
diff --git a/framework/source/constant/containerquery.cxx b/framework/source/constant/containerquery.cxx
index 57dc4a2fe768..c2d6ac9b7b54 100644
--- a/framework/source/constant/containerquery.cxx
+++ b/framework/source/constant/containerquery.cxx
@@ -23,8 +23,8 @@
namespace framework{
namespace constant{
-const sal_Unicode ContainerQuery::SEPERATOR_PARAM = (sal_Unicode)':';
-const sal_Unicode ContainerQuery::SEPERATOR_VALUE = (sal_Unicode)'=';
+const sal_Unicode ContainerQuery::SEPARATOR_PARAM = (sal_Unicode)':';
+const sal_Unicode ContainerQuery::SEPARATOR_VALUE = (sal_Unicode)'=';
} // namespace constant
} // namespace framework
diff --git a/framework/source/fwe/classes/framelistanalyzer.cxx b/framework/source/fwe/classes/framelistanalyzer.cxx
index c291e42bc81c..5322e6b275e5 100644
--- a/framework/source/fwe/classes/framelistanalyzer.cxx
+++ b/framework/source/fwe/classes/framelistanalyzer.cxx
@@ -66,7 +66,7 @@ FrameListAnalyzer::~FrameListAnalyzer()
In case the request was "CloseWin" these splitted lists can be used too, to decide if the last window
or document was closed. Then we have to initialize the backing window ...
Last but not least we must know something about our special help frame. It must be handled
- seperatly. And last but not least - the backing component frame must be detected too.
+ separately. And last but not least - the backing component frame must be detected too.
*/
void FrameListAnalyzer::impl_analyze()
diff --git a/framework/source/fwi/classes/protocolhandlercache.cxx b/framework/source/fwi/classes/protocolhandlercache.cxx
index de1f68ff9435..cefbe4e96065 100644
--- a/framework/source/fwi/classes/protocolhandlercache.cxx
+++ b/framework/source/fwi/classes/protocolhandlercache.cxx
@@ -235,9 +235,9 @@ void HandlerCFGAccess::read( HandlerHash** ppHandler ,
for( nSource=0; nSource<nSourceCount; ++nSource )
{
OUStringBuffer sPath( SETNAME_HANDLER );
- sPath.append(CFG_PATH_SEPERATOR);
+ sPath.append(CFG_PATH_SEPARATOR);
sPath.append(lNames[nSource]);
- sPath.append(CFG_PATH_SEPERATOR);
+ sPath.append(CFG_PATH_SEPARATOR);
sPath.append(PROPERTY_PROTOCOLS);
lFullNames[nTarget] = sPath.makeStringAndClear();
diff --git a/framework/source/inc/constant/containerquery.hxx b/framework/source/inc/constant/containerquery.hxx
index f5bda1baeb92..1467f9b05977 100644
--- a/framework/source/inc/constant/containerquery.hxx
+++ b/framework/source/inc/constant/containerquery.hxx
@@ -29,8 +29,8 @@ struct ContainerQuery
{
public:
- static const sal_Unicode SEPERATOR_PARAM;
- static const sal_Unicode SEPERATOR_VALUE;
+ static const sal_Unicode SEPARATOR_PARAM;
+ static const sal_Unicode SEPARATOR_VALUE;
};
} // namespace constant
diff --git a/framework/source/inc/loadenv/loadenv.hxx b/framework/source/inc/loadenv/loadenv.hxx
index a1065ce6945d..f8c78193eb7b 100644
--- a/framework/source/inc/loadenv/loadenv.hxx
+++ b/framework/source/inc/loadenv/loadenv.hxx
@@ -532,7 +532,7 @@ private:
throw(LoadEnvException, css::uno::RuntimeException);
/** @short because showing of a frame is needed more then once ...
- it's implemented as an seperate method .-)
+ it's implemented as an separate method .-)
@descr Note: Showing of a frame is bound to a special feature ...
a) If we recycle any existing frame, we must bring it to front.
diff --git a/framework/source/services/frame.cxx b/framework/source/services/frame.cxx
index 1641efd19523..3fff17d34392 100644
--- a/framework/source/services/frame.cxx
+++ b/framework/source/services/frame.cxx
@@ -3136,7 +3136,7 @@ void Frame::impl_checkMenuCloser()
// -----------------------------
// b)
// There is no other frame ... means no other document frame. The help module
- // will be handled seperatly and must(!) be ignored here ... excepting weself includes the help.
+ // will be handled separately and must(!) be ignored here ... excepting weself includes the help.
else if (
(aAnalyzer.m_lOtherVisibleFrames.getLength()==0) &&
(!aAnalyzer.m_bReferenceIsHelp ) &&
diff --git a/framework/source/services/pathsettings.cxx b/framework/source/services/pathsettings.cxx
index 4734eb2eb27a..b2e2dd0563ae 100644
--- a/framework/source/services/pathsettings.cxx
+++ b/framework/source/services/pathsettings.cxx
@@ -51,7 +51,7 @@
#define CFGPROP_WRITEPATH OUString("WritePath")
/*
- 0 : old style "Template" string using ";" as seperator
+ 0 : old style "Template" string using ";" as separator
1 : internal paths "Template_internal" string list
2 : user paths "Template_user" string list
3 : write path "Template_write" string
diff --git a/framework/source/uielement/langselectionstatusbarcontroller.cxx b/framework/source/uielement/langselectionstatusbarcontroller.cxx
index 5b1059c0d513..d8d5451bce02 100644
--- a/framework/source/uielement/langselectionstatusbarcontroller.cxx
+++ b/framework/source/uielement/langselectionstatusbarcontroller.cxx
@@ -238,7 +238,7 @@ throw (::com::sun::star::uno::RuntimeException)
subPopupMenu->insertItem( MID_LANG_PARA_MORE, String( FwkResId( STR_LANGSTATUS_MORE )), 0, MID_LANG_PARA_MORE );
// add last two entries to main menu
- xPopupMenu->insertSeparator( MID_LANG_PARA_SEPERATOR );
+ xPopupMenu->insertSeparator( MID_LANG_PARA_SEPARATOR );
xPopupMenu->insertItem( MID_LANG_PARA_STRING, String( FwkResId( STR_SET_LANGUAGE_FOR_PARAGRAPH )), 0, MID_LANG_PARA_STRING );
xPopupMenu->setPopupMenu( MID_LANG_PARA_STRING, subPopupMenu );
diff --git a/framework/source/jobs/joburl.cxx b/framework/source/jobs/joburl.cxx
index d42e23593f37..29874615c0ae 100644
--- a/framework/source/jobs/joburl.cxx
+++ b/framework/source/jobs/joburl.cxx
@@ -55,8 +55,8 @@ JobURL::JobURL( /*IN*/ const OUString& sURL )
sal_Int32 t = JOBURL_PROTOCOL_LEN;
do
{
- // seperate all token of "{[event=<name>],[alias=<name>],[service=<name>]}"
- OUString sToken = sURL.getToken(0, JOBURL_PART_SEPERATOR, t);
+ // separate all token of "{[event=<name>],[alias=<name>],[service=<name>]}"
+ OUString sToken = sURL.getToken(0, JOBURL_PART_SEPARATOR, t);
OUString sPartValue ;
OUString sPartArguments;
@@ -294,8 +294,8 @@ void JobURL::impldbg_checkIt()
JobURL::impldbg_checkURL("vnd.sun.star.job:service=;" , E_UNKNOWN, "" , "" , "" , NULL, NULL, NULL);
// check combinations
// Note: No additional spaces or tabs are allowed after a seperator occurred.
// Tab and spaces before a seperator will be used as value!
JobURL::impldbg_checkURL("vnd.sun.star.job:event=onMyEvent;alias=myAlias;service=css.Service" , E_EVENT | E_ALIAS | E_SERVICE , "onMyEvent", "myAlias", "css.Service" , NULL, NULL, NULL);
JobURL::impldbg_checkURL("vnd.sun.star.job:service=css.Service;alias=myAlias" , E_ALIAS | E_SERVICE , "" , "myAlias", "css.Service" , NULL, NULL, NULL);
JobURL::impldbg_checkURL("vnd.sun.star.job:service=css.Service ;alias=myAlias" , E_ALIAS | E_SERVICE , "" , "myAlias", "css.Service ", NULL, NULL, NULL);
@@ -294,8 +294,8 @@ void JobURL::impldbg_checkIt()
JobURL::impldbg_checkURL("vnd.sun.star.job:service=;" , E_UNKNOWN, "" , "" , "" , NULL, NULL, NULL);
// check combinations
- // Note: No additional spaces or tabs are allowed after a seperator occurred.
- // Tab and spaces before a seperator will be used as value!
+ // Note: No additional spaces or tabs are allowed after a separator occurred.
+ // Tab and spaces before a separator will be used as value!
JobURL::impldbg_checkURL("vnd.sun.star.job:event=onMyEvent;alias=myAlias;service=css.Service" , E_EVENT | E_ALIAS | E_SERVICE , "onMyEvent", "myAlias", "css.Service" , NULL, NULL, NULL);
JobURL::impldbg_checkURL("vnd.sun.star.job:service=css.Service;alias=myAlias" , E_ALIAS | E_SERVICE , "" , "myAlias", "css.Service" , NULL, NULL, NULL);